#
# spec file for package rtl-sdr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
%define libname librtlsdr%{sover}
%define rtlsdr_group rtlsdr

Name:           rtl-sdr
Version:        2.0.2
Release:        bp160.1.7
Summary:        Support programs for RTL2832
License:        GPL-2.0-or-later
URL:            http://sdr.osmocom.org/trac/wiki/rtl-sdr
#Git-Clone:     https://git.osmocom.org/rtl-sdr
Source:         https://github.com/steve-m/librtlsdr/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         0001-Better-udev-handling.patch
BuildRequires:  cmake >= 3.7.2
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)

%description
Programs that controls Realtek RTL2832 based DVB dongle in raw mode, so
it can be used as a SDR receiver.

%package -n %{libname}
Summary:        SDR driver for RTL2832
Requires:       %{name}-udev
Conflicts:      librtlsdr2

%description -n %{libname}
Library to run Realtek RTL2832 based DVB dongle as a SDR receiver.

%package udev
Summary:        Udev rules for RTL2832
Requires(pre):  shadow

%description udev
Udev rules for rtl-sdr driver

%package devel
Summary:        Development files for rtl-sdr
Requires:       %{libname} = %{version}

%description devel
Library headers for rtl-sdr driver.

%prep
%autosetup -p1

%build
%cmake \
  -DINSTALL_UDEV_RULES=ON \
  -DUDEV_RULES_PATH=%{_udevrulesdir} \
  -DUDEV_RULES_GROUP=%{rtlsdr_group} \
  -DDETACH_KERNEL_DRIVER=ON \
  -DENABLE_ZEROCOPY=ON
%cmake_build

%install
%cmake_install
rm %{buildroot}%{_libdir}/librtlsdr.a

%ldconfig_scriptlets -n %{libname}

%pre udev
getent group %{rtlsdr_group} >/dev/null || groupadd -r %{rtlsdr_group}

%post udev
%udev_rules_update

%postun udev
%udev_rules_update

%files
%license COPYING
%doc AUTHORS README
%{_bindir}/rtl_adsb
%{_bindir}/rtl_biast
%{_bindir}/rtl_eeprom
%{_bindir}/rtl_fm
%{_bindir}/rtl_power
%{_bindir}/rtl_sdr
%{_bindir}/rtl_tcp
%{_bindir}/rtl_test

%files -n %{libname}
%{_libdir}/librtlsdr.so.%{sover}*
%{_libdir}/librtlsdr.so.2*

%files udev
%{_udevrulesdir}/rtl-sdr.rules

%files devel
%{_libdir}/librtlsdr.so
%{_includedir}/rtl-sdr.h
%{_includedir}/rtl-sdr_export.h
%{_libdir}/pkgconfig/librtlsdr.pc
%{_libdir}/cmake/rtlsdr

%changelog
* Mon Jul 29 2024 Martin Pluskal <mpluskal@suse.com>
- Add conflict for library package with librtlsdr2
- Small spec file modernisation
* Sat Jun 15 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version (tag) 2.0.2
  * lib: set SOVERSION back to 0
  * r82xx: improve tuner precision and avoid redundant register
    writes for speed
  * fix: round gain input to nearest value
  * fix: set fc0012 gain to low on init
  * use library paths from pkg-config
- version number set in CmakeList.txt is still 2.0.1, workaround added
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Fri Nov  3 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.1
  * Fixup release that contains an updated debian/changelog
* Thu Nov  2 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.0.0
  * add direct sampling to rtl_sdr
  * add -D direct sampling flag to rtl_tcp
  * add blog v4 upconverter gpio switch
  * fix rtl_tcp error on windows when hints not initialized to 0
  * add rtl-sdr blog v4 support
  * Fix signal handler from getting stuck in an endless loop
  * lib: Stop applying workaround for libusb < 1.0.9
  * lib: force wait state after cancel of usb transfer
  * rtl_fm: add a new option to select 2nd direct sampling mode
  * rtl_tcp: put new DEFAULT_* constants in defines
  * rtl_tcp: Extracted some constants out of printf strings
  * cmake: populate pkgconfig file with prefix
  * Add rtl_biast as install target
  * tuner_r82xx: fix short-write in r82xx_read
  * Fix for CMake < 3.12.0
  * Add missing rtlsdrConfig.cmake
  * rtl_tcp: Initialize listensocket
  * rtl_tcp: Add IPv6 support
  * Use udev uaccess rules
  * rtl_fm/rtl_power: Improve scanning range parsing
  * Improve librtlsdr.pc file
  * lib: enable better UHF reception (>862MHz) for FC0013
  * set CMake policy CMP0075 if it exists
  * rtl_biast: Add rtl_biast
  * lib: Add GPIO version of the bias tee configuration API
  * rtl_eeprom: fix warnings
  * lib: disable usbfs zero-copy support by default
  * lib: fix memory leak in rtlsdr_open()
  * lib: Add workaround for Linux usbfs mmap() bug
- Drop not longer needed patches
  * rtl-sdr-0001-mmap-bug-arm.patch
  * rtl-sdr-0002-fix-rtlsdr_open-memory-leak.patch
  * rtl-sdr-0004-fix-rtl_eeprom-warnings.patch
  * rtl-sdr-0006-add-rtl_biast.patch
  * rtl-sdr-0009-fix-FC0013-UHF-reception.patch
  * rtl-sdr-0010-improve-librtlsdr_pc.patch
  * rtl-sdr-0011-improve-rtl_power--scanning-range-parsing.patch
  * rtl-sdr-0013-add-IPV6-for-rtl_tcp.patch
  * rtl-sdr-0014-initialize-listensocket_in-rtl_tcp.patch
  * rtl-sdr-0015-modernize-cmake-usage.patch
  * rtl-sdr-0019-fix-short-write-in-r82xx_read.patch
  * rtl-sdr-0021-rtl_fm-add-option-for-2nd-direct-sampling-mode.patch
  * rtl-sdr-0022-add-rtl-sdr-blog-v4-support.patch
- Update patch:
  * 0001-Better-udev-handling.patch
* Sat Sep  9 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- new patch rtl-sdr-0022-add-rtl-sdr-blog-v4-support.patch adding
  support for new funcionality in RTL-SDR v4 dongle (taken from git
  tree)
- fix for one minor rpmlint error
* Mon Jan 31 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- new patch rtl-sdr-0021-add-option-for-2nd-direct-sampling-mode.patch
  adding extra option to rtl_fm (borrowed from git tree)
* Thu Jul 22 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- patches:
    rtl-sdr-0003-disable-zerocopy-by-default.patch
    rtl-sdr-0007-allow-build-rtlsdr-as-subroject.patch
    rtl-sdr-0008-add-CMP0075-policy.patch
    rtl-sdr-0016-add-missing-rtlsdrConfig.patch
    rtl-sdr-0017-add-rtl_biast-as-install-target.patch
    rtl-sdr-0018-fix-for-older-cmake.patch
    rtl-sdr-0020-populate-pkgconfig-with-prefix.patch
  merged into rtl-sdr-0015-modernize-cmake-usage.patch
- patch rtl-sdr-0005-add-rtlsdr_set_bias_tee_gpio.patch
  merged into rtl-sdr-0006-add-rtl_biast.patch
* Tue Jul  6 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Added patches to upgrade to latest git head (only significant
  changes), including:
    + rtl-sdr-0001-mmap-bug-arm.patch
    + rtl-sdr-0002-fix-rtlsdr_open-memory-leak.patch
    + rtl-sdr-0003-disable-zerocopy-by-default.patch
    + rtl-sdr-0004-fix-rtl_eeprom-warnings.patch
    + rtl-sdr-0005-add-rtlsdr_set_bias_tee_gpio.patch
    + rtl-sdr-0006-add-rtl_biast.patch
    + rtl-sdr-0007-allow-build-rtlsdr-as-subroject.patch
    + rtl-sdr-0008-add-CMP0075-policy.patch
    + rtl-sdr-0009-fix-FC0013-UHF-reception.patch
    + rtl-sdr-0010-improve-librtlsdr_pc.patch
    + rtl-sdr-0011-improve-rtl_power--scanning-range-parsing.patch
    + rtl-sdr-0012-use-udev-uaccess_rules.patch (not used)
    + rtl-sdr-0013-add-IPV6-for-rtl_tcp.patch
    + rtl-sdr-0014-initialize-listensocket_in-rtl_tcp.patch
    + rtl-sdr-0015-modernize-cmake-usage.patch
    + rtl-sdr-0016-add-missing-rtlsdrConfig.patch
    + rtl-sdr-0017-add-rtl_biast-as-install-target.patch
    + rtl-sdr-0018-fix-for-older-cmake.patch
    + rtl-sdr-0019-fix-short-write-in-r82xx_read.patch
    + rtl-sdr-0020-populate-pkgconfig-with-prefix.patch
  * Full bias tee support for RTL-SDR v3 dongle
  * Command line utility rtl_biast for controlling bias tee
  * IPV-6 support for rtl_tcp
  * Fixed some bugs and compile time issues
* Tue Aug 28 2018 mpluskal@suse.com
- Use more of cmake macros
- Disable developer output from cmake
* Mon Aug 27 2018 mardnh@gmx.de
- Update to version 0.6.0
  * Fix inline functions to use 'static inline'
  * tuner_r82xx: turn off loop-through, remove dead code
  * rtl_adsb: fix hanging upon a signal in Fedora 27
  * lib: use USB zero-copy transfers if possible
* Sun Jun 10 2018 plinnell@opensuse.org
- Update to 0.5.4
  * No change log found in source or wiki
  * Drop git-requirement
* Fri Dec 15 2017 mpluskal@suse.com
- Update to version 0.5.3+git.20170919:
  * fix for msvc14
  * Add option '-T' for activating bias-T in rtl_(adsb|fm|power|tcp)
  * rtl_tcp: add command for bias tee control
  * lib: Use GPIO P0 to toggle an (optional) bias-t
  * lib: fix direction bit in GPIO code
* Thu Jun 15 2017 wk@ire.pw.edu.pl
- Update to version 0.5.3+git.20170612:
  * lib: use GPIO0 to control bias tee
  * rtl_(adsb|fm|power|tcp): add option -T for activating bias tee
* Sun Apr 23 2017 mardnh@gmx.de
- Use package-meta for tar_scm service and add git-core
  to BuildRequires
* Sun Apr 23 2017 mpluskal@suse.com
- Update group handling
* Sat Apr 15 2017 mardnh@gmx.de
- Add patch: 0001-Better-udev-handling.patch
- Use proper cmake options
- Use group rtlsdr in the udev-rules
* Thu Mar 23 2017 jengelh@inai.de
- RPM group fix
* Mon Mar  6 2017 mpluskal@suse.com
- Update to version 0.5.3+git.20161127:
  * lib: change default number of transfers to 15
  * rtl_tcp: make all global variables static
  * cmake: include resource file for MSVC builds
  * Correct return code of e4k_reg_write().
  * Allow setting bandwidth for R820T
  * New functions rtlsdr_set_tuner_bandwidth()
  * tools: allow built-in functions for newer versions of MSVC
  * lib: check for libusb init failure
  * lib: add new HanfTek dongle
- Packaging changes:
  * Add _service for easier updating of package
  * Split udev rules to separate package
  * Run spec-cleaner
* Sun Mar  5 2017 mpluskal@suse.com
- Use cmake macros
* Sun Dec  4 2016 dl8fcl@darc.de
- update to version 0.5.3_13_ge3e6ee2
  add new HanfTek dongle
* Wed Jun 10 2015 dl8fcl@darc.de
- update to version 0.5.3_12_ge3c03f7
  check for libusb init failure
* Sat May 16 2015 dl8fcl@darc.de
- update to version 0.5.3_10_g8b4d755
  Allow setting bandwidth for R820T
* Fri Sep  5 2014 dl8fcl@darc.de
- update to version 0.5.3_6_gd447a2e
* Fri Dec 20 2013 dl8fcl@darc.de
- update to version 0.5.2_2_g5f38c05
* Sun Nov  3 2013 lnt-sysadmin@lists.lrz.de
- Changes to spec file:
  * Update udev paths for openSUSE 13.1 and ensure udev rules are
    updated when package is installed / updated / uninstalled.
  * Define %%libname to ease reuse of %%post(un) macros
* Fri Nov  1 2013 dl8fcl@darc.de
- update to version 0.5.1
* Sun Sep 22 2013 dl8fcl@darc.de
- update to version 0.5.0_git20130915
* Tue Jul 23 2013 lnt-sysadmin@lists.lrz.de
- update to version 0.5.git
  * adds support for ASUS U3100MINI_PLUS_V2
  * set DETACH_KERNEL_DRIVER=ON to allow detaching of kernel driver
* Mon Jun 10 2013 dl8fcl@darc.de
- update to version git20130608
  minor enhancements
* Sun Apr 28 2013 dl8fcl@darc.de
- update to version git20130417.
  minor enhancements
* Thu Apr 11 2013 lnt-sysadmin@lists.lrz.de
- small changes to the spec file:
  * pass %%optflags to cmake according to
    http://en.opensuse.org/openSUSE:Build_system_recipes
  * use config(noreplace) for udev rules file
* Fri Mar 22 2013 dl8fcl@darc.de
- import into the hamradio repository
